Acknowledgements
================

The concept of this project is largely inspired in the `pdb-tools <https://github.com/haddocking/pdb-tools>`_ *one script one action* idea, here we pushed this concept further.
Thanks to `JoaoRodrigues <https://github.com/JoaoRodrigues>`_ for all the mentoring on MD. CI in this repository provided by `cookiecutter-pylibrary <https://github.com/ionelmc/cookiecutter-pylibrary>`_, with final personalized modifications.
